import { request } from 'umi';
import { getDataBaseUrl } from '@/global_data';
function Page(params) {
   return request(getDataBaseUrl()+`/api/user/userpage`,{method:'post',data:params});
}

//启用
function Enable(params)
{
 return request(getDataBaseUrl()+`/api/user/enable/?Id=${params}`)
}
//禁用
 function Disable(params)
{
 return request(getDataBaseUrl()+`/api/user/disable/?Id=${params}`)
}

//删除
function RemoveUser(params) {
    return request(getDataBaseUrl()+'/api​/user/delete', {
      method: 'POST',
      data: params
    });
}

function  Add(params) {
    return request(getDataBaseUrl()+'/api​/user/add', {
        method: 'POST',
        data: params
      });
}

function  Update(params) {
    return request(getDataBaseUrl()+'/api​/user/update', {
        method: 'POST',
        data: params
      });
}

function ResetPwd(params) {
  return request(getDataBaseUrl()+`/api/user/resetuserpwd/?Id=${params}`);
}

function  UpdatePwd(params) {
  return request(getDataBaseUrl()+'/api/user/updatepwd', {
    method: 'POST',
    data: params
  });
}

function  GetRoleDic() {
  return request(getDataBaseUrl()+`/api/roles/getrole`);
}

function  GetUserRole(params) {
  return request(getDataBaseUrl()+`/api/user/getuserrole?UserId=${params}`);
}

function  AddUserRole(params) {
  return request(getDataBaseUrl()+'/api/user/adduserrole', {
    method: 'POST',
    data: params
  });
}

function  UpdateUserRole(params) {
  return request(getDataBaseUrl()+'/api/user/updateuserrole', {
    method: 'POST',
    data: params
  });
}
//数据授权
export async function SetDataRole(params) {
  return request(getDataBaseUrl()+`/api/user/setandalteruserscope`,{
    method:'post',
    data:params
  });
}

function gettree(params) {
  return request(getDataBaseUrl()+'​/api​/sysOrg​/tree', {
    data: {
      ...params,
    },
  });
}

 function gettree2(params) {
  return request(getDataBaseUrl()+'​/api​/organize/tree', {
    method: 'GET',
    data: {
      ...params,
    },
  });
}

export default {
  Page,
  Enable,
  Disable,
  RemoveUser,
  Update,
  Add,
  ResetPwd,
  UpdatePwd,
  GetRoleDic,
  GetUserRole,
  AddUserRole,
  UpdateUserRole,
  SetDataRole,
  gettree,
  gettree2
};
